#
# spec file for package audacity
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg
%bcond_with mad
%bcond_with twolame

Name:           audacity
BuildRequires:  alsa-devel
# we use internal PortAudio(so it is not included here in BuildRequires), because audacity team grab sources
# from Portaudio's svn more frequently than we (e.g. see support for non-mmap devices like pulseaudio)
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  jack-devel
BuildRequires:  libexpat-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libvorbis-devel
BuildRequires:  soundtouch-devel
BuildRequires:  taglib-devel
BuildRequires:  update-desktop-files
%if %suse_version > 1130
BuildRequires:  wxWidgets-wxcontainer-devel
%else
BuildRequires:  wxGTK-devel
%endif
#vamp-plugin-sdk-devel is available since openSUSE 11.2
%if %suse_version > 1110
BuildRequires:  vamp-plugin-sdk-devel
%endif
%if %{with ffmpeg}
BuildRequires:  libffmpeg-devel
%endif
%if %{with mad}
BuildRequires:  libmad-devel
%endif
%if %{with twolame}
BuildRequires:  libtwolame-devel
%endif
Version:        1.3.13
Release:        1.pm.56.1
License:        GPLv2+
Summary:        A Free, Cross-Platform Digital Audio Editor
Url:            http://audacity.sourceforge.net/
Group:          Productivity/Multimedia/Sound/Editors and Convertors
Source:         %{name}-minsrc-%{version}-beta.tar.bz2
Source1:        %{name}.png
Source2:        %{name}-license-nyquist
# PATCH-FIX-OPENSUSE %{name}-no_buildstamp.patch reddwarf@opensuse.org -- this patch removes the buildstamp
Patch0:         %{name}-no_buildstamp.patch
Patch16:        %{name}-implicit.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %suse_version > 1130
%define _use_internal_dependency_generator 0
%define __find_requires %wx_requires
%endif

%description
Audacity is a program that manipulates digital audio wave forms. In
addition to recording sounds directly from within the program, it
imports many sound file formats, including WAV, AIFF, AU, IRCAM, MP,
and Ogg Vorbis.  With Audacity, you can edit wave data larger than the
physical memory size of your computer.

%prep
%setup -q -n %{name}-src-%{version}-beta
%patch0
%patch16
%{__cp} %{S:2}  LICENSE_NYQUIST.txt

%build
#%{?suse_update_config:%{suse_update_config -f . lib-src/*/.}}
#export AUTOMAKE="automake --foreign"
%configure \
    --enable-unicode \
    --with-libvorbis=system \
%if %{with ffmpeg}
    --with-ffmpeg=system \
%else
    --without-ffmpeg \
%endif
%if %{with mad}
    --with-libmad=system \
%else
    --without-libmad \
%endif
%if %{with twolame}
    --with-libtwolame=system \
%else
    --without-libtwolame \
%endif
    --with-libsndfile=system \
    --with-libflac=system \
    --with-ladspa \
    --with-libid3tag=system \
    --with-libsamplerate=system
%{__make} %{?_smp_mflags}

%install
%makeinstall
%suse_update_desktop_file audacity
%{__install} -v -d -m755 %{buildroot}%{_datadir}/pixmaps
%{__install} -v -m 644 %{SOURCE1} %{buildroot}%{_datadir}/pixmaps
#delete default icon we have nicer - transparent :)
%__rm %{buildroot}%{_datadir}/pixmaps/*.xpm
# we will add docs later in %files section
%__rm -rf %{buildroot}%{_datadir}/doc/audacity
%find_lang %{name}

%clean
rm -rf %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%doc LICENSE.txt README.txt LICENSE_NYQUIST.txt
%doc %{_mandir}/man?/*
%{_bindir}/audacity
%{_datadir}/audacity
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_datadir}/mime/packages/audacity.xml
%{_datadir}/icons/hicolor/*

%changelog
* Mon Apr 18 2011 detlef@links2linux.de
- Update to version 1.3.13
  * Numerous bug fixes
  - Crashes on Windows when clicking in the track or in effects dialogs.
  - Crashes on OS X when closing or quitting.
  - Warning (on by default) now provided when importing uncompressed audio
    files and when read-directly uncompressed files are missing.
  - Full support added for later versions of the optional FFmpeg library up
    to current FFmpeg HEAD. More compatible U-Law/A-Law exports.
  - VST effects processing restored to full speed. Hang fixed when launching
    on OS X 10.5 PPC with VST effects present.
  - (OS X) Files imported from iTunes could create invalid characters in the
    .aup project file. See here for help re-opening older projects that have
    this error.
  - (Linux) Crashes or stalled recordings using the pulse device. Crashes
    using Play-at-Speed if Audacity was configured with libsamplerate.
  * Changes and Improvements
  - Control Toolbar renamed to Transport Toolbar. Input/output selection
    moved from Mixer Toolbar to improved Device Toolbar (on by default).
  - New "Sync-Lock Tracks" feature (turned on in the Tracks menu).
  - Equalization now supports importing and exporting curves. Noise Removal
    improvements including new option to isolate noise.
  - Improved Automatic Crash Recovery with all project changes autosaved.
  - New "Extended Import" Preferences for specifying audio file importers.
  - (Windows and Linux) Close button now quits on closing the last window
    while File > Close clears to a new, empty project.
* Tue Dec 28 2010 sbrabec@suse.cz
- Compile with wxWidgets-wxcontainer, it does not compile with STL
  variant.
* Mon Oct  4 2010 reddwarf@opensuse.org
- Cleaned with spec-cleaner
- Fix support for newer ffmpeg versions
- Use download/verify services
- Add -implicit patch as suggested by post-build scripts
* Fri Jun  4 2010 mseben@novell.com
- add LICENSE_NYQUIST.txt to clarify licensing of libnyquist source
  files
* Wed May 26 2010 cmorve69@yahoo.es
- Fix build-compare
- Fix ffmpeg support
* Sat Apr 17 2010 cmorve69@yahoo.es
- Updated no_buildstamp patch.
* Tue Apr 13 2010 davejplater@gmail.com
- Update to version 1.3.12
- Bug fixes for:
  * Imports and Exports:
  * AAC files could not be exported at 48000 Hz
  * When importing multiple native file formats using FFmpeg, all
    files after the first reverted to using the native importer
  * FFmpeg custom export window too large on 800 x 600 resolution
    monitors
  * Projects froze if files imported via On-Demand were no longer
    available
  * (Linux) WAV/AIFF exports were corrupted if overwriting an aliased
    file which had been imported using the command line
  * Labels:
  * Cutting or deleting a region in the waveform and label track did
    not move the labels in advance of the cut
  * Incorrect behavior snapping to labels and boundaries when Snep To
    was enabled
  * Labels can now be reversed if included with the audio selection
  * Other bug fixes:
  * When using non-English languages, Generate effects truncated the
    selected region
  * Mice with high-precision scroll-wheels could cause a crash
  * Changing recording preferences using the Transport menu did
    not update the menu in other open projects
  * (Windows 7) Clicking in a file open or save dialog caused files or
    folders to disappear from the list, and file filtering was broken
- Changes and improvements:
  * A hover tooltip is now provided if the Mixer Toolbar input selector
    cannot control the system slider for the selected input.
  * More intuitive behavior when moving and resizing labels by dragging
  * Support added for importing lists of files (LOF) containing relative
    paths
  * Export Multiple: new option to use a numerical prefix before existing
    label or track names; "Success" dialog now resizable
  * New Equalization preset "Inverse RIAA", with new button to invert
    other curves
  * Timer Record now remembers last scheduled duration
  * Meter Toolbar can now be made much narrower, and so more suitable for
    vertical orientation
  * New Preferences choice for "System" language which is used on first
    run instead of asking user to choose language
  * Warning now provided if WAV/AIFF exports are not successfully
    completed
  * (Linux) Improved icon set in compliance with freedesktop.org
    Icon Theme Specification 0.6
* Mon Mar 15 2010 coolo@novell.com
- rework previous fix without autoreconf in patching configure
  directly
* Mon Mar 15 2010 dimstar@opensuse.org
- Add audacity-nomac.patch: remove the mac checks from configure.
  The check is actually build a test program which fails due to
  missing headers. As consequence: start autoreconf in
  lib-src/portmixer.
* Mon Jan 25 2010 mseben@novell.com
- updated to 1.3.11
  - Bug fixes for:
  * Too much audio exported when exporting partial selections
  * Exports via FFmpeg corrupted if included metadata; M4A now supports metadata export
  * Nyquist plug-ins did not add labels to an existing label track
  * Crash opening Preferences when no audio devices available
  * Timer Record and Sound Activated Recording bugs
  * (Windows) Installer now installs correctly over previous Audacity versions
  * Miscellaneous crashes and interface issues
  - Improvements:
  * (Windows) Higher resolution icon file
  * New Sound Finder plug-in for labelling regions of audio
* Fri Jan  8 2010 vuntz@opensuse.org
- Remove unneeded glib-devel BuildRequires.
* Sun Dec 13 2009 cmorve69@yahoo.es
- Remove buildstamp to help build-compare
* Tue Dec  8 2009 mseben@novell.com
- Update to 1.3.10
  - Bug fixes
  * Freeze importing audio files when Default View Mode set to Pitch (EAC)
  * Simultaneous On-Demand imports sorted incorrectly
  * WAV or AIFF files imported as noise if Preferences set to copy in the data at 24-bit quality
  * WMA exports corrupted if they contained metadata
  * Metadata Editor appeared before the Export window when exporting to any format
  * Crash or hang using Equalization on longer tracks
  * Reverse did not reverse clip boundaries
  * Nyquist - Excessive memory consumption led to slow processing or crashes
  * Nyquist - Values appearing in text boxes not always the default or previously entered values
  * Nyquist - Errors running in European locales where comma used as decimal separator
  * VST effects remained in Effect menu even when re-scanned and no longer available
  * Truncate Silence produced incorrect results if silences spanned a block boundary
  * Spurious "not writable/disk full" errors when saving projects
  * Playing, rendering or exporting multiple tracks led to desynchronized playback or loss of audio data
  * Crash opening Preferences when no recording and/or playback devices enabled or connected
  * Preferences window: OK button did not respond to ENTER when a tab selected in left-hand panel
  * Mixer Board solo button handling
  * (Windows) After a period launching correctly, Audacity sometimes did not come up on top at launch
  * (Mac OS X) Correctly installed Help folder could not be found
  * (Mac OS X and Linux) Output slider could affect VU playback meter which then did not reflect actual waveform volume level
  * (Linux) Undoing or redoing a label edit could cause a crash
  - Changes and improvements:
  * Linked audio and label tracks disabled until a future Beta version so they can be bug fixed
  * Input volume slider will be disabled if it doesn't have proper control of system slider; use the system slider instead
  * Proper support for copying/pasting label-with-audio including label text; new Edit > Paste Text to New Label menu item to paste system clipboard
  * Contrast Tool now modeless, more intuitive handling of multiple project windows, various other minor improvements
- obsolete gsocket-conflict.patch
* Thu Nov  5 2009 davejplater@gmail.com
- Update to 1.3.9 adapted patches and remade audacity-1.3.9-audiodevdefaults.patch
  * Crash, slow launch or excessive CPU/memory use arising from automatic VST support:
    o VST instrument plug-ins should now be correctly ignored
    o VST effects now scanned only at start of first session that detects them, then cached
    o Effects are now not loaded or opened until needed
    o New "Effects" tab in Preferences to enable/disable VST effects and enable VST rescan on next launch
  * Default View Mode now works
  * Chains now always apply their stored parameters rather than those last used in Effect menu
  * Non-MP3 files imported via drag or Recent Files caused crash if filter in file open window set to MP3
  * AAC exports (using the optional FFmpeg library) silenced
  * Generating audio always fitted the project in the window; fit now done only if generating in new track
  * View menu items/shortcuts incorrectly disabled when playing or recording
  * DTMF generator defaulted to zero duration on open
  * Unwanted interactions between linked audio and label tracks
  * Various other interface bugs
  * Compressor: new option to compress based on peaks, improved attack and decay time support
  * Mixer Board: improved design, more responsive meters and now interacts fully with Track Panel in main window
* Fri Jul 31 2009 mseben@suse.cz
-  added vamp-plugin-sdk-devel to buildrequires (for 11.2 and higher)
* Thu Jul 23 2009 mseben@suse.cz
- update to 1.3.8 see full changelog : http://audacity.sourceforge.net/download/features-1.3-a
  Effects and Analysis:
  * VST Effects now display GUI by default
  * Faster Equalization and Noise Removal;
  * Chains applied to files now clear temporary data after processing each file
  * Updated Nyquist implementation with support for SAL syntax and improved memory management
  * Plot Spectrum now analyzes up to 237.8 seconds of audio, with separate windows
  for each project and improved display; new preferences for Spectrograms
  * Contrast Analysis tool now modeless for easier use
  Interface:
  * Draft Manual/Quick Help included in Windows and Mac installers
  * New "Mixer Board" view with per-track VU meters
  * Mute, solo, gain, pan and track height saved in projects
  * More compact Preferences window with easier-to-use Keyboard tab and new toolbars shortcuts
  * New Screenshot Tools and improved screen reader support
  Other:
  * Record more than 16 channels (hardware/drivers permitting)
  * Improved support for non-mmap ALSA devices such as PulseAudio
  * 32-bit float data over 0 dB now handled without clipping
  * "Stop" option when importing preserves already imported data
  * AMR NB export now supported if the optional FFmpeg library is installed
  * Faster waveform drawing and better response in multi-track projects
- obsolete : return_non_void.patch,endian-fix.patch,font-fix.patch,
    strict-aliasing.patch,wxGTK_with_stl.patch,modal-help-dialog.patch,
    desktop_file.patch,portaudio-non-mmap-alsa.patch,startup_fix.patch
- added gsocket-conflict.patch to fix GSocket conflict
- added taglib-devel to BR
* Fri May 29 2009 mseben@suse.cz
- fix startup crash (startup_fix.patch)
* Thu May 21 2009 cmorve69@yahoo.es
- Got portaudio-non-mmap-alsa.patch and audiodevdefaults.patch from
  Fedora to allow it to work with PulseAudio
* Tue May 19 2009 cmorve69@yahoo.es
- Add alsa-devel BR to allow ALSA output
* Mon May 11 2009 cmorve69@yahoo.es
- removed unneeded BuildRequires
- make ffmpeg, mad and twolame support build options
- use upstream .desktop file
- do not force -fno-strict-aliasing since upstream already does
* Wed Apr  8 2009 mseben@suse.cz
- added wxGTK_with_stl.patch to fix build issues when linking wxGTK
  configured with --enable-stl flag
* Mon Feb 23 2009 mseben@suse.cz
- added return_non_void.patch to fix non-void return value (bnc#477654)
* Mon Feb  2 2009 mseben@suse.cz
- updated to version 1.3.7
  Bug Fixes:
  * Muting/soloing caused incorrect channel results in exported
  stereo files
  * Nyquist effects: pasted unmodified audio into the result,
  no progress bar, truncation of processed audio on cancel
  * Noise Removal: pasted unmodified audio into the result, unwanted
  filtering tail
  * Uncompressed exports: export as WAV could be corrupted if
  overwriting to same file, export multiple to uncompressed formats
  only produced 16-bit WAV
  * Compressed exports: MP3 exports now produce correct bit rate
  mode, quality and length, with improved metadata visibility
  in player applications, WMA exports containing metadata are now correct
  * Restored support for multi-channel recording devices that can
  record more than two channels using Audacity
  * fixes for spurious clipping, label typing, no shortcuts after
  running effects
  * project rate now always changes to respect that of first imported file
  New Features:
  * F11 Full Screen mode, high-quality "Sliding Time Scale/Pitch Shift"
  effect, Audio Contrast Analyzer
  Other changes:
  * As a first step towards improving latency correction, a fixed
  rather than variable correction is now applied
  * Numerous minor interface fixes and improvements
- obsolete *-compile.patch, *-locale.patch
* Mon Jan 12 2009 mseben@suse.cz
- fixed Khmer translation file (*-locale.patch)
- added array-delete.patch to fix array delete  (bnc#442936)
- added transparent desktop icon (audacity.png)
- obsolete *-portaudio-shlib.patch, *-nosse.patch
* Thu Dec 11 2008 mseben@suse.cz
- updated to version 1.3.6
  Interface:
  * "Save Compressed Copy of Project" saves in much smaller .OGG
    format to facilitate online transmission of projects
  * Improved MIDI import and export routines, and clearer color
    for selection region
  * Default temporary directory on Mac now accessible in Finder
  Import / Export:
  * Stability improvements in on-demand loading
  * FFmpeg: support for latest version of library, improved
    version checks and error messages, stability improvements
    in custom exporter
  Bug Fixes:
  * Crash in "Get Noise Profile" step of Noise Removal at project
    rates below 20480 Hz.
  * Underestimation of peak level in tracks with a small number
    of different peaks
  * Truncate Silence could result in repeated or lost audio if
    applied to the whole of a track
  * Other interface, generating, exporting and platform-specific
    fixes
  Compilation:
  * Added autoconf macro archive to CVS, enabling *.nix users
    without this archive to build --with -MIDI
- renamed *-modal-help-dialog.diff to *-modal-help-dialog.patch,
  also changed for 1.3.6 tarball
- added libexpat-devel to BuildRequires (directory lib-src/expat
  in tarball 1.3.6 no longer exists)
* Thu Nov 20 2008 tiwai@suse.de
- fix modal dialog with the help browser (bnc#440032)
* Wed May 28 2008 anosek@suse.cz
- updated to version 1.3.5
  Recording / Playback
  * Several bugs fixed so that latency correction should be better, and more devices work correctly.
  * Problems with invalid sample rates under Linux should be much rarer.
  * Newer version of Portaudio library.
  * New feature to record onto the end of an existing track (hold Shift while clicking Record).
  Import / Export
  * Updated versions of Libogg, Libvorbis, Libflac, Libsndfile and Twolame libraries.
  * Handling of unsupported file formats more informative.
  * Handling of file names with slashes on OS X improved.
  * New dialog allows replacement of illegal file name characters on all platforms.
  Interface
  * Improved scaling and layout for rulers and VU meters.
  * Envelope fixes/improvements including full control of undo/redo.
  * New keyboard shortcuts and improved menu navigation.
  * Preferences:
    o More intuitive tab arrangement.
    o New options for mute/solo and Metadata Editor behavior.
    o Language can now be changed without restart.
  * Expanded Build Information tab.
  Effects
  * New Vocal Remover plug-in, improvements for Generate effects.
- dropped obsoleted patches (cflags.patch) (CVE-2007-6061.patch)
* Wed May 14 2008 schwab@suse.de
- Remove useless patch.
* Wed Apr  2 2008 anosek@suse.cz
- fixed Insecure symlink handling (bnc#344588) (CVE-2007-6061.patch)
  - temp file is now created in users home directory
* Fri Jan 25 2008 adrian@suse.de
- remove mad-devel in BuildRequires to keep the package as part
  of Factory
* Fri Jan 18 2008 anosek@suse.cz
- updated to version 1.3.4
  New features
    New Welcome Screen with introduction to Audacity.
    New keyboard command: 'Mix and Render to New Track' (bound to Ctrl+Shift+M).
    New keyboard shortcut: "Shift-A" starts playback when stopped, or performs "Stop and Select" when playing.
    Added support for VAMP audio analysis plug-ins.
    Solo button solos only one track at a time, and a track cannot be both mute and solo.
  Interface
    Keyboard shortcuts for making short/long jumps along the timeline.
    Added 'Snap To' in the Selection Bar.
    Made keyboard navigation easier when multiple menu items with the same first letter exist.
    Enhanced interface for label editing.
    Layout of OK/Cancel buttons consistency improved.
    Preferences:
  * "Select all audio in project, if none selected" (on by default).
  * "Beep on completion of longer activities" (system bell, not main output).
  * Other preferences cleaned up and explanations improved.
    Envelopes: Many fixes when copying / pasting / repeating.
    Many translation updates.
    Track height fixed in several cases.
    CleanSpeech mode switching without closing and re-opening fixed.
  Opening/Saving Formats
    Metadata editor added for OGG, FLAC and WAV/AIFF exports, and general improvements.
    Metadata import improved.
    Muted tracks are no longer audible in the exported mix.
  Effects
    Truncate Silence: support for multiple and stereo tracks.
    Dtmf Generator:
  * Added support for keypad letters.
  * Added an amplitude control.
    Compressor: variable decay time added.
    Equalization:
  * Clicks at start / end prevented.
  * Improvements to saved curves being found.
  * Preview works correctly.
    'Merge' command appears in Undo history.
    Clipping detected more reliably.
    Nyquist plug-ins reviewed and enhanced.
    Better (and more) progress bars.
    Cancelling effect always restores previous audio.
    Several improvement to effects in batch mode.
  Recording/Playback
    Improvements to latency correction.
    Updated version of portaudio-v19 library.
  Note that Help is no longer built in, but accessible on the Web via links in Audacity.
- dropped obsoleted patches:
  * flac.patch - already in upstream
  * equalization.patch - already in upstream
  * build.patch
  * hu_update.patch.bz2
- added patch to fix compilation errors (compile.patch)
* Wed Sep 19 2007 prusnak@suse.cz
- fix broken Equalization effect (equalization.patch) [#326217]
* Thu Aug  2 2007 anosek@suse.cz
- fixed Hungarian translation update [#295657] (hu_update.patch)
* Thu Jun 21 2007 sbrabec@suse.cz
- Build with system soundtouch.
- Build with jack support.
* Wed Jun  6 2007 sbrabec@suse.cz
- Removed invalid desktop Category "Application" (#254654).
* Tue May 29 2007 prusnak@suse.cz
- updated to 1.3.3
  * added collapse/expand tracks
  * multiple clips per track
  * added selection bar
  * improved label tracks
  * better performance with large projects
  * added transcription toolbar
  * improved accessibility for the visually impaired
  * added auto-save and automatic crash recovery
  * added batch processing
  * metadata may be added to OGG files
  * EQ effect responsiveness improved
  * new Auto Duck effect
  * DTMF tone generator
- dropped obsoleted patches:
  * ambigous.patch
  * overflow-fix.patch (included in update)
  * qualification.patch (included in update)
  * wx-compat.patch
- added patches:
  * flac.patch - adjust for new FLAC 1.1.4 API
  * nosse.patch - don't try to use SSE on non-x86 archs
* Fri Apr 20 2007 schwab@suse.de
- Fix quoting in autoconf macros.
* Thu Aug 10 2006 anosek@suse.cz
- fixed build with new version of autotools (audacity-build.patch)
* Sun Feb 19 2006 stbinner@suse.de
- add GenericName to .desktop file
* Wed Feb 15 2006 sbrabec@suse.cz
- Build with portaudio19 (#151210).
* Mon Jan 30 2006 aj@suse.de
- Further fix to BuildRequires.
* Sun Jan 29 2006 aj@suse.de
- Fix buildrequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 16 2005 sbrabec@suse.cz
- Returned back required wx-compat patch.
* Wed Dec  7 2005 sbrabec@suse.cz
- Updated to version 1.2.4b.
* Wed Nov  9 2005 sbrabec@suse.cz
- Strict aliasing fix.
* Tue Oct 25 2005 sbrabec@suse.cz
- Fixed extra qualification.
- Build with correct CFLAGS.
- Fixed random return values.
* Fri Oct 14 2005 sbrabec@suse.cz
- Disabled mad support.
* Fri Apr 15 2005 mcihar@suse.de
- add SDL-devel-packages because of wxGTK
* Thu Feb 17 2005 hvogel@suse.de
- mark as nosrc
* Tue Nov 23 2004 ro@suse.de
- fix build with current wxGTK
* Mon Nov 22 2004 mcihar@suse.cz
- update to 1.2.3
* Mon Sep  6 2004 mcihar@suse.cz
-fix build on 64-bit arches
* Fri Sep  3 2004 mcihar@suse.cz
- update to 1.2.2
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 1.2.1.
- using wxGTK-compat library.
* Sun Mar 28 2004 tiwai@suse.de
- fixed the segfault at the start up (bug #34313)
- fixed the size of fonts for wxGTK with GTK-2.
- fixed possible buffer overflows.
- build with portaudio-v18, v19 seems problematic.
* Fri Mar  5 2004 tiwai@suse.de
- updated to version 1.2.0 final.
* Mon Feb 16 2004 tiwai@suse.de
- updated to version 1.2.0-pre4.
* Thu Jan 22 2004 tiwai@suse.de
- fixed the build with the latest autoconf.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 1.2.0-pre3.
- use portaudio v19 (shared lib).
* Tue Jan 13 2004 tiwai@suse.de
- fixed the neededforbuild for the latest wxGTK with gtk2.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon.
* Sun Sep 14 2003 adrian@suse.de
- add AudioVideoEditing Category
* Fri Aug 29 2003 tiwai@suse.de
- fixed the bug of WAVE display.
* Thu Aug 14 2003 tiwai@suse.de
- added desktop file.
* Mon Aug 11 2003 tiwai@suse.de
- updated to version 1.2.0-pre1.
- help file is installed under /usr/share/audacity.
* Thu Jul  3 2003 tiwai@suse.de
- fixed neededforbuild for the recent update of mad.
* Mon May 26 2003 ro@suse.de
- removed unpackaged files from buildroot
* Thu Mar 27 2003 tiwai@suse.de
- updated to version 1.1.3.
  linked with libFLAC and libsamplerate.
* Tue Nov 26 2002 tiwai@suse.de
- updated to version 1.1.1.
- build with the system libsndfile since now audacity supports
  libsndfile 1.0.
- enabled nyquist support.
* Fri Aug 30 2002 tiwai@suse.de
- updated to version 1.1.0 cvs 2002.08.30.
  the 1.1.0 tarball version has a major bug regarding to project
  file management (bug #18662).  this version fixes the problem.
  also, this one includes a help text, which wasn't there.
* Wed Jul 24 2002 tiwai@suse.de
- updated to version 1.1.0.
* Mon Jul  1 2002 tiwai@suse.de
- updated to the stable version 1.0.0-2.
* Wed Apr 17 2002 tiwai@suse.de
- fixed build with gcc-3.1.
* Wed Apr 10 2002 ro@suse.de
- work around autoconf problem: first AC_CHECK_HEADER
  apparently has to be outside of an if ... fi block
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Fri Jan 25 2002 ro@suse.de
- added libpng,libjpeg,libtiff to neededforbuild
* Thu Jan 24 2002 tiwai@suse.de
- initial package version: 0.98.
- built with the shared id3lib.
